==> ble_provider-0.0.2.tar.gz: lib/ble_provider.dart <==
import 'dart:async';
import 'package:flutter/services.dart';
import 'indoor_location.dart';

class BleProvider {
  static const MethodChannel _channel = const MethodChannel('ble_provider');
  static Function(IndoorLocation) callback = (IndoorLocation location) {};

  static Future<dynamic> callHandler (MethodCall methodCall) async {
    switch (methodCall.method) {
      case 'locationCallback':
        BleProvider.locationCallback(methodCall.arguments);
        break;
      case "onProviderStarted":
        print('BLE provider started');
        break;
      case "onProviderStopped":
        print("BLE provider stopped");
        break;
      case 'onProviderError':
        print('provider error: ${methodCall.arguments}');
        break;
      default:
        throw MissingPluginException('notImplemented');
    }
  }

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<void> init (String polestarKey) async {
    _channel.setMethodCallHandler((call) => callHandler(call));
    await _channel.invokeMethod("init", {"key": polestarKey});
  }

  static Future<bool> setLocationCallback (Function(IndoorLocation) callback) async {
    BleProvider.callback = callback;
    final bool result = await _channel.invokeMethod("setLocationCallback");
    return result;
  }

  static Future<void> locationCallback(e) async {
    BleProvider.callback(IndoorLocation.fromMap(e));
  }

  static Future<bool> start() async {
    final bool started = await _channel.invokeMethod("start");
    return started;
  }

  static Future<bool> stop() async {
    final bool stopped = await _channel.invokeMethod("stop");
    return stopped;
  }
}

==> ble_provider-0.0.3.tar.gz: lib/ble_provider.dart <==
import 'dart:async';
import 'package:flutter/services.dart';
import 'indoor_location.dart';

class BleProvider {
  static const MethodChannel _channel = const MethodChannel('ble_provider');
  static Function(IndoorLocation) callback = (IndoorLocation location) {};

  static Future<dynamic> callHandler(MethodCall methodCall) async {
    switch (methodCall.method) {
      case 'locationCallback':
        BleProvider.locationCallback(methodCall.arguments);
        break;
      case "onProviderStarted":
        print('BLE provider started');
        break;
      case "onProviderStopped":
        print("BLE provider stopped");
        break;
      case 'onProviderError':
        print('provider error: ${methodCall.arguments}');
        break;
      default:
        throw MissingPluginException('notImplemented');
    }
  }

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<void> init(String polestarKey) async {
    _channel.setMethodCallHandler((call) => callHandler(call));
    await _channel.invokeMethod("init", {"key": polestarKey});
  }

  static Future<bool> setLocationCallback(
      Function(IndoorLocation) callback) async {
    BleProvider.callback = callback;
    final bool result = await _channel.invokeMethod("setLocationCallback");
    return result;
  }

  static Future<void> locationCallback(e) async {
    BleProvider.callback(IndoorLocation.fromMap(e));
  }

  static Future<bool> start() async {
    final bool started = await _channel.invokeMethod("start");
    return started;
  }

  static Future<bool> stop() async {
    final bool stopped = await _channel.invokeMethod("stop");
    return stopped;
  }
}
